@@ -1,5 +1,5 @@
 package Bio::ToolBox::Data::core;
-our $VERSION = '1.40';
+our $VERSION = '1.50';
 
 =head1 NAME
 
@@ -19,6 +19,7 @@ use base 'Bio::ToolBox::Data::file';
 use Bio::ToolBox::db_helper qw(
 	open_db_connection
 	verify_or_request_feature_types
+	$BAM_ADAPTER
 );
 
 1;
@@ -738,6 +739,25 @@ sub _column_is_stranded {
 #### Database methods ##############################################################
 
 sub open_database {
+	my $self = shift;
+	if (not defined $_[0]) {
+		return $self->open_meta_database;
+	}
+	elsif ($_[0] eq '0' or $_[0] eq '1') {
+		# likely a boolean value to indicate force
+		return $self->open_meta_database($_[0]);
+	}
+	elsif ($_[0] =~ /[a-zA-Z]+/) {
+		# likely the name of a database
+		return $self->open_new_database(@_);
+	}
+	else {
+		# original default
+		return $self->open_meta_database(@_);
+	}
+}
+
+sub open_meta_database {
 	my $self = shift;
 	my $force = shift || 0;
 	return unless $self->{db};
@@ -751,10 +771,15 @@ sub open_database {
 	return $db;
 }
 
-sub verify_dataset {
+sub open_new_database {
 	my $self = shift;
-	my $dataset = shift;
-	my $database = shift; # name or object?
+	my $database = shift;
+	my $force = shift || 0;
+	return open_db_connection($database, $force);
+}
+
+sub verify_dataset {
+	my ($self, $dataset, $database) = @_;
 	return unless $dataset;
 	if (exists $self->{verfied_dataset}{$dataset}) {
 		return $self->{verfied_dataset}{$dataset};
@@ -765,7 +790,7 @@ sub verify_dataset {
 			$self->{verfied_dataset}{$dataset} = $dataset;
 			return $dataset;
 		}
-		$database ||= $self->open_database;
+		$database ||= $self->open_meta_database;
 		my ($verified) = verify_or_request_feature_types(
 			# normally returns an array of verified features, we're only checking one
 			db      => $database,
@@ -931,6 +956,14 @@ sub database {
 	return $self->{db};
 }
 
+sub bam_adapter {
+	my $self = shift;
+	if (@_) {
+		$BAM_ADAPTER = shift;
+	}
+	return $BAM_ADAPTER;
+}
+
 sub gff {
 	my $self = shift;
 	if (defined $_[0] and $_[0] =~ /^(?:0|1|2|2\.5|3)$/) {
@@ -1231,13 +1264,14 @@ sub _find_column_indices {
 	# these do not include parentheses for grouping
 	# non-capturing parentheses will be added later in the sub for proper 
 	# anchoring and grouping - long story why, don't ask
-	my $name   = $self->find_column('^name|geneName|transcriptName|geneid|id|alias');
-	my $type   = $self->find_column('^type|class|primary_tag');
+	my $name   = $self->find_column('^name|gene.?name|transcript.?name|geneid|id|gene|alias');
+	my $type   = $self->find_column('^type|class|primary_tag|biotype');
 	my $id     = $self->find_column('^primary_id');
 	my $chromo = $self->find_column('^chr|seq|ref|ref.?seq');
 	my $start  = $self->find_column('^start|position|pos|txStart');
 	my $stop   = $self->find_column('^stop|end|txEnd');
 	my $strand = $self->find_column('^strand');
+	my $score  = $self->find_column('^score$');
 	$self->{column_indices} = {
 		'name'      => $name,
 		'type'      => $type,
@@ -1248,6 +1282,7 @@ sub _find_column_indices {
 		'stop'      => $stop,
 		'end'       => $stop,
 		'strand'    => $strand,
+		'score'     => $score,
 	};
 	return 1;
 }
@@ -1305,6 +1340,12 @@ sub id_column {
 	return $self->{column_indices}{id};
 }
 
+sub score_column {
+	my $self = shift;
+	carp "score_column is a read only method" if @_;
+	$self->_find_column_indices unless exists $self->{column_indices};
+	return $self->{column_indices}{score};
+}
 
 
 #### Special Row methods ####
@@ -1338,11 +1379,23 @@ columns), and special file format structure.
 
 =item open_database
 
+This is wrapper method that tries to do the right thing and passes 
+on to either open_meta_database() or open_new_database() methods. 
+Basically a legacy method for open_meta_database().
+
+=item open_meta_database
+
 Open the database that is listed in the metadata. Returns the 
 database connection. Pass a true value to force a new database 
 connection to be opened, rather than returning a cached connection 
 object (useful when forking).
 
+=item open_new_database($database)
+
+Convenience method for opening a second or new database that is 
+not specified in the metadata, useful for data collection. This 
+is a shortcut to Bio::ToolBox::db_helper::open_db_connection().
+
 =item verify_dataset($dataset)
 
 Verifies the existence of a dataset or data file before collecting 
@@ -1503,6 +1556,11 @@ Returns the index of the column that best represents the type.
 Returns the index of the column that represents the Primary_ID 
 column used in databases.
 
+=item score_column
+
+Returns the index of the column that represents the Score 
+column in certain formats, such as GFF, BED, bedGraph, etc.
+
 =item get_seqfeature
 
 Returns the stored SeqFeature object for a given row.
